Skip site navigation (1)Skip section navigation (2)
Date:      Mon, 6 Aug 2001 00:54:37 +0200
From:      =?iso-8859-1?Q?Kjetil_=D8degaard?= <kjetilod@orakel.ntnu.no>
To:        ports@FreeBSD.org
Subject:   Patch: audio/mp3asm
Message-ID:  <20010806005437.A2668@orakel.ntnu.no>

next in thread | raw e-mail | index | archive | help

--IJpNTDwzlM2Ie8A6
Content-Type: text/plain; charset=us-ascii
Content-Disposition: inline

The mp3asm port is broken; src/mp3asm.c defines getprogname(), which
conflicts with a declaration in stdlib.h.

Putting the attached patch in the 'files' directory of the port fixes
the problem.

-- 
Kjetil

--IJpNTDwzlM2Ie8A6
Content-Type: text/x-csrc; charset=us-ascii
Content-Disposition: attachment; filename="patch-src::mp3asm.c"

--- src/mp3asm.c.orig	Mon Aug  6 00:25:01 2001
+++ src/mp3asm.c	Thu Apr 12 06:16:24 2001
@@ -54,12 +54,12 @@
 output_t *output;
 
 /*
  * getprogname: sets me to be the name of the executable.
  *
  */
 
 char *
+xgetprogname(const char *argv0)
-getprogname(const char *argv0)
 {
   char *string;
   (string = strrchr(argv0, '/')) ? string++ : (string = (char *)argv0);
@@ -200,7 +200,7 @@
 int
 main(int argc, char *argv[])
 { 
+  init_global (xgetprogname(argv[0]));
-  init_global (getprogname(argv[0]));
 
   parse_args (argc, argv);
 

--IJpNTDwzlM2Ie8A6--
@@ -54,12 +54,12 @@
 
 /*
+ * xgetprogname: sets me to be the name of the executable.
- * getprogname: sets me to be the name of the executable.
  *
  */

To Unsubscribe: send mail to majordomo@FreeBSD.org
with "unsubscribe freebsd-ports" in the body of the message




Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?20010806005437.A2668>